@@ -31,8 +31,8 @@ class SpanningNode(Node):
     """
     def __init__(self, node_type_name: str, content: List[List[str]], grid: 'Grid',
                  low_row: int, high_row: int, left_column: int, right_column: int,
-                 local_alignment: Optional[Alignment] = None):
-        super().__init__(node_type_name, content, grid, local_alignment)
+                 expansion: float, local_alignment: Optional[Alignment] = None):
+        super().__init__(node_type_name, content, grid, expansion, local_alignment)
         # Validate the span
         if low_row <= 0:
             raise BadRowNumber
