@@ -6,6 +6,7 @@ import sys
 import logging
 from pathlib import Path
 from flatland.flatland_exceptions import FlatlandIOException, MultipleFloatsInSameBranch
+from flatland.flatland_exceptions import LayoutParseError, ModelParseError
 from flatland.input.model_parser import ModelParser
 from flatland.input.layout_parser import LayoutParser
 from flatland.database.flatlanddb import FlatlandDB
@@ -52,7 +53,10 @@ class XumlClassDiagram:
             self.model = ModelParser(model_file_path=self.xuml_model_path, debug=False)
         except FlatlandIOException as e:
             sys.exit(e)
-        self.subsys = self.model.parse()
+        try:
+            self.subsys = self.model.parse()
+        except ModelParseError as e:
+            sys.exit(e)
 
         self.logger.info("Parsing the layout")
         # Parse the layout
@@ -60,7 +64,10 @@ class XumlClassDiagram:
             self.layout = LayoutParser(layout_file_path=self.flatland_layout_path, debug=False)
         except FlatlandIOException as e:
             sys.exit(e)
-        self.layout = self.layout.parse()
+        try:
+            self.layout = self.layout.parse()
+        except LayoutParseError as e:
+            sys.exit(e)
 
         # Load the flatland database
         self.db = FlatlandDB(rebuild=self.rebuild)
@@ -89,12 +96,23 @@ class XumlClassDiagram:
             cp = self.layout.connector_placement
             for r in self.subsys.rels:  # r is the model data without any layout info
                 rnum = r['rnum']
-                rlayout = cp[rnum]  # How this r is to be laid out on the diagram
+                rlayout = cp.get(rnum)  # How this r is to be laid out on the diagram
+                if not rlayout:
+                    self.logger.warning(f"Relationship {rnum} skipped, no placement in layout sheet.")
+                    continue
+
                 if 'superclass' in r.keys():
                     self.draw_generalization(rnum=rnum, generalization=r, tree_layout=rlayout)
                 else:
                     self.draw_association(rnum=rnum, association=r, binary_layout=rlayout)
 
+            # Check to see if any connector placements were specified for non-existent relationships
+            rnum_placements = {r for r in cp.keys()}
+            rnum_defs = {r['rnum'] for r in self.subsys.rels}
+            orphaned_placements = rnum_placements - rnum_defs
+            if orphaned_placements:
+                self.logger.warning(f"Connector placements {orphaned_placements} in layout sheet refer to undeclared relationships")
+
         self.logger.info("Rendering the Canvas")
         self.flatland_canvas.render()
 
@@ -125,7 +143,10 @@ class XumlClassDiagram:
             self.logger.info(f'Processing class: {cname}')
 
             # Get the layout data for this class
-            nlayout = np[cname]
+            nlayout = np.get(cname)
+            if not nlayout:
+                self.logger.warning(f"Skipping class [{cname}] -- No placement specified in layout sheet")
+                continue
 
             # Layout data for all placements
             # By default the class name is all on one line, but it may be wrapped across multiple
@@ -160,6 +181,8 @@ class XumlClassDiagram:
             for i, p in enumerate(nlayout['placements']):
                 h = HorizAlign[p.get('halign', 'CENTER')]
                 v = VertAlign[p.get('valign', 'CENTER')]
+                expansion_percent = max(min(100, nlayout.get('node_expansion', 0)), 1)
+                expansion_ratio = round(expansion_percent / 100, 2)
                 # If this is an imported class, append the import reference to the attribute list
                 row_span, col_span = p['node_loc']
                 # If methods were supplied, include them in content
@@ -175,7 +198,8 @@ class XumlClassDiagram:
                         content=text_content,
                         grid=self.flatland_canvas.Diagram.Grid,
                         row=row_span[0], column=col_span[0],
-                        local_alignment=Alignment(vertical=v, horizontal=h)
+                        local_alignment=Alignment(vertical=v, horizontal=h),
+                        expansion=expansion_ratio
                     )
                 else:
                     # Span might be only 1 column or row
@@ -189,7 +213,8 @@ class XumlClassDiagram:
                         grid=self.flatland_canvas.Diagram.Grid,
                         low_row=low_row, high_row=high_row,
                         left_column=left_col, right_column=right_col,
-                        local_alignment=Alignment(vertical=v, horizontal=h)
+                        local_alignment=Alignment(vertical=v, horizontal=h),
+                        expansion=expansion_ratio
                     )
         return nodes
         # TODO:  Add support for axis offset on stem names
@@ -199,6 +224,7 @@ class XumlClassDiagram:
         # Straight or bent connector?
         tstem = binary_layout['tstem']
         pstem = binary_layout['pstem']
+        reversed = False  # Assume that layout sheet and model order matches
         astem = binary_layout.get('tertiary_node', None)
 
         t_side = association['t_side']
@@ -208,7 +234,8 @@ class XumlClassDiagram:
             # The node_ref is a list and the first element refers to the model class name
             # (the 2nd element indicates duplicate placement, if any, and is not relevant for the comparison above)
             tstem, pstem = pstem, tstem
-            self.logger.warning(f"Stems order in layout file does not match model, swapping stem order for connector {rnum}")
+            reversed = True
+            self.logger.info(f"Stems order in layout file does not match model, swapping stem order for connector {rnum}")
 
         t_phrase = StemName(
             text=TextBlock(t_side['phrase'], wrap=tstem['wrap']),
@@ -226,13 +253,33 @@ class XumlClassDiagram:
             side=pstem['stem_dir'], axis_offset=None, end_offset=None
         )
         node_ref = make_node_ref(pstem['node_ref'])
+        try:
+            pnode = self.nodes[node_ref]
+        except KeyError:
+            missing_side = "p-stem" if not reversed else "t-stem"
+            self.logger.error(f"In layout sheet {missing_side} of {rnum} class [{node_ref}] is not defined in model")
+            sys.exit()
         p_stem = New_Stem(stem_type='class mult', semantic=p_side['mult'] + ' mult',
-                          node=self.nodes[node_ref], face=pstem['face'],
+                          node=pnode, face=pstem['face'],
                           anchor=pstem.get('anchor', None), stem_name=p_phrase)
         # There is an optional stem for an association class
         if astem:
             node_ref = make_node_ref(astem['node_ref'])
-            a_stem = New_Stem(stem_type='associative mult', semantic=association['assoc_mult'] + ' mult',
+            try:
+                semantic = association['assoc_mult'] + ' mult'
+            except KeyError:
+                self.logger.error(
+                    f"Layout sheet calls for ternary stem, but class model does not specify any"
+                    f" association class on association: {rnum}")
+                sys.exit()
+            try:
+                node=self.nodes[node_ref]
+            except KeyError:
+                self.logger.error(
+                    f"Association class [{node_ref}] is missing in relationship {rnum}"
+                )
+                sys.exit()
+            a_stem = New_Stem(stem_type='associative mult', semantic=semantic,
                               node=self.nodes[node_ref], face=astem['face'], anchor=astem.get('anchor', None),
                               stem_name=None)
         else:
